@@ -8,11 +8,12 @@ from sqlalchemy_orm.base.mapper import MapperBase
 from sqlalchemy_orm.typemapper import TypeMapper
 
 
-class DataRMBase(MapperBase, InheritanceBase, HelperBase):
+class SQLAlchemyORMBase(MapperBase, InheritanceBase, HelperBase):
     pass
 
 
 class BaseDeclarativeMeta(DeclarativeMeta):
+
     def __init__(cls, classname, bases, dict_, **kw):
         dict_.update(cls.__dict__)
         super().__init__(classname, bases, dict_, **kw)
@@ -23,14 +24,14 @@ def base_factory(type_map=None, base=None):
         base.type_mapper = type_map
 
     if base:
-        combined_base = type("Base", (base, DataRMBase), {})
+        combined_base = type("Base", (base, SQLAlchemyORMBase), {})
     else:
-        combined_base = DataRMBase
+        combined_base = SQLAlchemyORMBase
 
     if base is None and type_map is not None:
         combined_base.type_mapper = type_map
 
-    model: DataRMBase = declarative_base(
+    model: SQLAlchemyORMBase = declarative_base(
         cls=combined_base,
         name="Base",
         metaclass=BaseDeclarativeMeta
